import java.net.*;
import java.io.*;
import java.util.*;

public class FetchResourceViaURLConnection {
  public static void main(String[] args) {

    URL url;
    BufferedReader reader;

    // Default url.
    String urlStr = "http://www.ii.uib.no/~khalid/pgjc2e/";

    if (args.length > 0)
      urlStr = args[0];

    try {
      // (1) Create an URL instance with the address of the resource.
      url = new URL( urlStr );
      System.out.println( url );

      // (2) Obtain an URLConnection from the URL instance.
      URLConnection connection = url.openConnection();

      // (3) Customize any request fields and setup parameters.
      connection.setRequestProperty("User-Agent",
                        "Mozilla/4.0 (compatible; JavaApp)");
      connection.setRequestProperty("Referer",
                        "http://www.ii.uib.no/");
      connection.setUseCaches(false);
      printRequestHeaders(connection);

      // (4) Establish a connection to the remote resource.
      connection.connect();

      // (5) Query response header fields.
      printResponseHeaders(connection);
      // Print all header fields
      printHeaderFields(connection);

      // (6) Access the resource content.
      InputStream input = connection.getInputStream();
      reader = new BufferedReader(
                  new InputStreamReader(input));

      System.out.println("Reading the contents ...");
      for(;;) {
        String line = reader.readLine();
        if (line == null) break;
        System.out.println(line);
      }

    } catch (MalformedURLException mfue) {
        System.out.println("Protocol missing or unkown");
    } catch (IOException ioe) {
        System.out.println("Error while reading");
    }
  }

  public static void printRequestHeaders(URLConnection connection) {
    System.out.println("REQUEST HEADER FIELDS");

    System.out.println("User-Agent: " +
                        connection.getRequestProperty("User-Agent"));
    System.out.println("Referer:    " +
                        connection.getRequestProperty("Referer"));
  }

  public static void printResponseHeaders(URLConnection connection) {
    System.out.println("RESPONSE HEADER FIELDS");

    System.out.println("Content-Type:     "
                       + connection.getContentType());
    System.out.println("Content-Length:   "
                       + connection.getContentLength());
    System.out.println("Content-Encoding: "
                       + connection.getContentEncoding());
    System.out.println("Date:             "
                       + connection.getDate());
    System.out.println("Expiration-Date:  "
                       + connection.getExpiration());
    System.out.println("Last-modified:    "
                       + connection.getLastModified());
  }

  public static void printHeaderFields(URLConnection connection) {
    System.out.println("ALL HEADER FIELDS");

    Map allFields = connection.getHeaderFields();
    System.out.println("No. of field headers: " + allFields.size());
    System.out.println(allFields);

    // Note that this loop will NOT write out all the fields
    // if a null key is found prematurely.
    for (int i = 0;; i++) {
        String key = connection.getHeaderFieldKey(i);
        if (key == null) break;
        String value = connection.getHeaderField(i);
        System.out.println(key + ": " + value);
    }
  }
}