// A Simple Browser: Use a JTextArea to display the contents.
import java.awt.*;
import java.awt.event.*;
import java.net.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import java.util.regex.*;

public class SearcherTextPlain extends JFrame {

   private JLabel keywordLabel;
   private JTextField keywordsTF;
   private JTextArea displayPane;

   // set up the GUI
   public SearcherTextPlain() {
      super( "Searcher" );

      // create keywords field and register its listener
      keywordLabel = new JLabel("Enter keywords, hit ENTER:");
      keywordsTF = new JTextField(20);
      keywordsTF.addActionListener(
         new ActionListener() {
            public void actionPerformed( ActionEvent event ) {
               getResource( keywordsTF.getText() );
            }
         }
      );

      // create displayPane.
      displayPane = new JTextArea();
      displayPane.setEditable( false );

      // create the layout
      Container container = getContentPane();
      JPanel keywordsPanel = new JPanel();
      keywordsPanel.add( keywordLabel );
      keywordsPanel.add( keywordsTF );
      container.add( keywordsPanel, BorderLayout.NORTH );
      container.add( new JScrollPane( displayPane ),
                     BorderLayout.CENTER );

      // set size and put up the GUI
      setSize( 800, 600 );
      setVisible( true );
   }

   private void getResource( String keywords ) {
      try {

         // Tag on the keywords.

         String request = "http://www.google.com/" +
                          "search?q=" +
                          URLEncoder.encode(keywords, "UTF8");

/*
         String request = "http://www.altavista.com/web/" +
                          "results?q=" +
                          URLEncoder.encode(keywords, "UTF8");
*/
/*
         String request = "http://finance.yahoo.com/" +
                          "q?s=ibm" +
                          URLEncoder.encode(keywords, "UTF8");
*/
//       String request = "http://localhost:80";
         System.out.println(request);

         // Obtain a HttpURLConnection.
         URL url = new URL(request);
         URLConnection urlConnection = url.openConnection();
         if (!(urlConnection instanceof HttpURLConnection))
            throw new MalformedURLException("Not http protocol");
         HttpURLConnection connection = (HttpURLConnection)
                                         urlConnection;

         // Set method and appropriate header fields.
         connection.setRequestMethod("GET");  // Default
         connection.setRequestProperty("User-Agent",
                          "Mozilla/4.0 (compatible; JavaApp)");
         connection.setRequestProperty("Referer",
                          "http://www.ii.uib.no/");

         // Establish a connection to the remote resource.
         connection.connect();

         // Check if the response is ok.
         if (connection.getResponseCode() !=
            HttpURLConnection.HTTP_OK)
            throw new IOException("Response not ok");

         printStatusLineInfo(connection);
         printHeaderFields(connection);

         String content = readText(connection);
         System.out.println(content);
         displayPane.setText(content);

      } catch (ProtocolException pe) {
         JOptionPane.showMessageDialog( this,
            pe.toString(), "Bad Protocol",
            JOptionPane.ERROR_MESSAGE );
      } catch (MalformedURLException mue) {
         JOptionPane.showMessageDialog( this,
            mue.toString(), "Bad URL",
            JOptionPane.ERROR_MESSAGE );
      } catch (IOException ioe) {
         JOptionPane.showMessageDialog( this,
            ioe.toString(), "Bad Request/Response",
            JOptionPane.ERROR_MESSAGE );
      }
   }

  public static String readText(URLConnection connection)
                  throws IOException {
      InputStream input = connection.getInputStream();
      BufferedReader reader = new BufferedReader(
                  new InputStreamReader(input));
      String content = "";
      for(;;) {
        String line = reader.readLine();
        if (line == null) break;
        content += line + "\n";
                        // Character.LINE_SEPARATOR; // Doesn't work!
      }
      return content;
  }

  public static void printStatusLineInfo(
                HttpURLConnection connection)
                  throws IOException {
    System.out.println("STATUS LINE INFORMATION");
    System.out.println("Response code:     "
                       + connection.getResponseCode());
    System.out.println("Response message:  "
                       + connection.getResponseMessage());
  }

  public static void printHeaderFields(URLConnection connection) {
    System.out.println("ALL HEADER FIELDS");

    Map allFields = connection.getHeaderFields();
    System.out.println("No. of field headers: " + allFields.size());
    System.out.println(allFields);

    // Note that this loop will NOT write out all the fields
    // if a null key is found prematurely.
    for (int i = 0;; i++) {
        String key = connection.getHeaderFieldKey(i);
        if (key == null) break;
        String value = connection.getHeaderField(i);
        System.out.println(key + ": " + value);
    }
  }

   public static void main( String[] args ) {
      SearcherTextPlain browser = new SearcherTextPlain();
      browser.setDefaultCloseOperation( JFrame.EXIT_ON_CLOSE );
   }
}